@@ -8,15 +8,22 @@
 //!
 //! These endpoints are used for querying projects merge requests.
 
+mod approve;
 pub mod awards;
 mod create;
 pub mod discussions;
 mod edit;
 mod issues_closed_by;
+mod merge;
 mod merge_request;
 mod merge_requests;
 pub mod notes;
+mod rebase;
 mod resource_label_events;
+mod unapprove;
+
+pub use self::approve::ApproveMergeRequest;
+pub use self::approve::ApproveMergeRequestBuilder;
 
 pub use self::create::CreateMergeRequest;
 pub use self::create::CreateMergeRequestBuilder;
@@ -28,6 +35,9 @@ pub use self::edit::MergeRequestStateEvent;
 pub use self::issues_closed_by::IssuesClosedBy;
 pub use self::issues_closed_by::IssuesClosedByBuilder;
 
+pub use self::merge::MergeMergeRequest;
+pub use self::merge::MergeMergeRequestBuilder;
+
 pub use self::merge_request::MergeRequest;
 pub use self::merge_request::MergeRequestBuilder;
 
@@ -38,5 +48,11 @@ pub use self::merge_requests::MergeRequestView;
 pub use self::merge_requests::MergeRequests;
 pub use self::merge_requests::MergeRequestsBuilder;
 
+pub use self::rebase::RebaseMergeRequest;
+pub use self::rebase::RebaseMergeRequestBuilder;
+
 pub use self::resource_label_events::MergeRequestResourceLabelEvents;
 pub use self::resource_label_events::MergeRequestResourceLabelEventsBuilder;
+
+pub use self::unapprove::UnapproveMergeRequest;
+pub use self::unapprove::UnapproveMergeRequestBuilder;
